@@ -266,7 +266,7 @@ def oms(fs, size, asd, fknee):
     Multiplying by (2π f / c)^2 to express it as fractional frequency deviations,
 
         S_oms(f) [ffd] = (2π asd / c)^2 [ f^2 + (fknee^4 / f^2) ]
-                      = (2π asd / c)^2 f^2 + (2π asd fknee^2 / c)^2 f^(-2).
+                       = (2π asd / c)^2 f^2 + (2π asd fknee^2 / c)^2 f^(-2).
 
     Note that the level of this noise depends on the interferometer and the type of beatnote.
 
@@ -283,22 +283,26 @@ def oms(fs, size, asd, fknee):
     return violet(fs, size, 2 * pi * asd / c) \
         + red(fs, size, 2 * pi * asd * fknee**2 / c)
 
-def jitter(fs, size, asd):
+def jitter(fs, size, asd, fknee):
     """Generate jitter for one angular degree of freedom.
 
     The power spectral density in angle is given by
 
-        S_jitter(f) [rad] = asd^2,
+        S_jitter(f) [rad] = asd^2 [ 1 + (fknee / f)^4 ],
 
     which is converted to angular velocity by mutliplying by (2π f)^2,
 
-        S_jitter(f) [rad/s] = (2π asd)^2 f^2.
+        S_jitter(f) [rad/s] = (2π asd)^2 [ f^2 + (fknee^4 / f^2) ]
+                            = (2π asd)^2 f^2 + (2π asd fknee^2)^2 f^(-2).
 
     Args:
         asd: amplitude spectral density [rad/sqrt(Hz)]
+        fknee: cutoff frequency [Hz]
     """
-    logger.debug("Generating jitter (fs=%s Hz, size=%s, asd=%s rad/sqrt(Hz))", fs, size, asd)
-    return violet(fs, size, 2 * pi * asd)
+    logger.debug("Generating jitter (fs=%s Hz, size=%s, asd=%s rad/sqrt(Hz), fknee=%s Hz)",
+        fs, size, asd, fknee)
+    return violet(fs, size, 2 * pi * asd) \
+        + red(fs, size, 2 * pi * asd * fknee**2)
 
 def dws(fs, size, asd):
     """Generate DWS measurement noise.
@@ -317,19 +321,20 @@ def dws(fs, size, asd):
     logger.debug("Generating DWS measurement (fs=%s Hz, size=%s, asd=%s rad/sqrt(Hz))", fs, size, asd)
     return violet(fs, size, 2 * pi * asd)
 
-def tcb_sync(fs, size, asd):
-    """TCB synchronization noise.
+def moc_time_correlation(fs, size, asd):
+    """MOC time correlation noise.
 
-    High-level noise model for the uncertainty we have in estimating
-    the TCB timer deviations, i.e., the equivalent TCB times for the
+    High-level noise model for the uncertainty we have in computing the MOC
+    time correlation (or time couples), i.e., the equivalent TCB times for the
     equally-sampled TPS timestamps.
 
     Assumed to be a white noise in timing,
 
-        S_tcbsnc(f) [s] = asd^2.
+        S_moc(f) [s] = asd^2.
 
     Args:
         asd: amplitude spectral density [s/sqrt(Hz)]
     """
-    logger.debug("Generating TCB synchronization noise (fs=%s Hz, size=%s, asd=%s s/sqrt(Hz))", fs, size, asd)
+    logger.debug("Generating MOC time correlation noise (fs=%s Hz, size=%s, "
+                 "asd=%s s/sqrt(Hz))", fs, size, asd)
     return white(fs, size, asd)
